==> haskell-tamarin-prover-accountability-1.10.0-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-accountability.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-accountability
version:              1.10.0
visibility:           public
id:                   tamarin-prover-accountability-1.10.0-A8zhPMjOdfA6eB7NZNxxls
key:                  tamarin-prover-accountability-1.10.0-A8zhPMjOdfA6eB7NZNxxls
license:              LicenseRef-GPL
copyright:            (c) 2019-2021 Robert Künnemann, Kevin Morio & Yavor Ivanov
maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Kevin Morio <kevin.morio@cispa.de>,
    Yavor Ivanov <yavor.ivanov@cispa.de>

homepage:             https://tamarin-prover.github.io/
synopsis:             Library for accountability for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides support for accountability verification.

category:             Theorem Provers
abi:                  c9cba7c558758722ebacc6fb31b8e94a
exposed:              True
exposed-modules:      Accountability Accountability.Generation
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/tamarin-prover-accountability-1.10.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/tamarin-prover-accountability-1.10.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/tamarin-prover-accountability-1.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-accountability
hs-libraries:
    HStamarin-prover-accountability-1.10.0-A8zhPMjOdfA6eB7NZNxxls

depends:
    aeson-2.1.2.1-nTcMAwSjFOFbKrX5mWkol
    aeson-pretty-0.8.10-Bn3MrqKITSRGoNuV6rGApo base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    dlist-1.0-E99MqJW5mmB4kr4PCgIESI exceptions-0.10.5
    fclabels-2.0.5.1-1QZtUUAvsjm7B08fefIuRV mtl-2.2.2
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy parsec-3.1.16.1
    process-1.6.18.0 raw-strings-qq-1.1-LjNtvZIthZV3ba6bu2kOwo
    safe-0.3.21-JtmveFmtp7AKwHntYKRiun
    tamarin-prover-term-1.10.0-CZQYH0fFkGY6ZsS4x4fkE5
    tamarin-prover-theory-1.10.0-E7qAfGu2WznKbkyHiz8slJ
    tamarin-prover-utils-1.10.0-4GO4gcvS6clHPvb0pTurLy text-2.0.2
    transformers-0.5.6.2 uniplate-1.6.13-4SF1ABu3og71xOEcZeSfwK

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-accountability/html/tamarin-prover-accountability.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-accountability/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-accountability-1.10.0-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-accountability.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-accountability
version:              1.10.0
visibility:           public
id:                   tamarin-prover-accountability-1.10.0-ExpaVWTQ3Dx36PirfI1kVp
key:                  tamarin-prover-accountability-1.10.0-ExpaVWTQ3Dx36PirfI1kVp
license:              LicenseRef-GPL
copyright:            (c) 2019-2021 Robert Künnemann, Kevin Morio & Yavor Ivanov
maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Kevin Morio <kevin.morio@cispa.de>,
    Yavor Ivanov <yavor.ivanov@cispa.de>

homepage:             https://tamarin-prover.github.io/
synopsis:             Library for accountability for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides support for accountability verification.

category:             Theorem Provers
abi:                  11059cf6bdb996201cab4c223d02fe26
exposed:              True
exposed-modules:      Accountability Accountability.Generation
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/tamarin-prover-accountability-1.10.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/tamarin-prover-accountability-1.10.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/tamarin-prover-accountability-1.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-accountability
hs-libraries:
    HStamarin-prover-accountability-1.10.0-ExpaVWTQ3Dx36PirfI1kVp

depends:
    aeson-2.1.2.1-1NeIvw5bSkQ9apxHmCtPBl
    aeson-pretty-0.8.10-2tNFY07YMRPWyoSCQYVlF base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    dlist-1.0-E99MqJW5mmB4kr4PCgIESI exceptions-0.10.5
    fclabels-2.0.5.1-3SMp9qGPU6IFaQ8ERA4OLn mtl-2.2.2
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy parsec-3.1.16.1
    process-1.6.18.0 raw-strings-qq-1.1-73kb7SizjX3bDDbE8dc5y
    safe-0.3.21-3kF9VX2rOl78iX2OdZTXNo
    tamarin-prover-term-1.10.0-2ovm5IofS7l2FbQB4Rf7py
    tamarin-prover-theory-1.10.0-C1pikW4dDa1EEzzp2aX7dV
    tamarin-prover-utils-1.10.0-JxbjvCRYzKf7w42VvskXZN text-2.0.2
    transformers-0.5.6.2 uniplate-1.6.13-CJ0oCvoijnU13momfUMYNw

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-accountability/html/tamarin-prover-accountability.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-accountability/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
